/****************************************************************************
** Meta object code from reading C++ file 'qwebviewloadinginfo.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwebview/src/webview/qwebviewloadinginfo.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwebviewloadinginfo.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19QWebViewLoadingInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto QWebViewLoadingInfo::qt_create_metaobjectdata<qt_meta_tag_ZN19QWebViewLoadingInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWebViewLoadingInfo",
        "RegisterEnumClassesUnscoped",
        "false",
        "url",
        "QUrl",
        "status",
        "LoadStatus",
        "errorString",
        "Started",
        "Stopped",
        "Succeeded",
        "Failed"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'url'
        QtMocHelpers::PropertyData<QUrl>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'status'
        QtMocHelpers::PropertyData<enum LoadStatus>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'errorString'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'LoadStatus'
        QtMocHelpers::EnumData<enum LoadStatus>(6, 6, QMC::EnumIsScoped).add({
            {    8, LoadStatus::Started },
            {    9, LoadStatus::Stopped },
            {   10, LoadStatus::Succeeded },
            {   11, LoadStatus::Failed },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QWebViewLoadingInfo, qt_meta_tag_ZN19QWebViewLoadingInfoE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWebViewLoadingInfo::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QWebViewLoadingInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QWebViewLoadingInfoE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19QWebViewLoadingInfoE_t>.metaTypes,
    nullptr
} };

void QWebViewLoadingInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QWebViewLoadingInfo *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->url(); break;
        case 1: *reinterpret_cast<enum LoadStatus*>(_v) = _t->status(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->errorString(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
