/****************************************************************************
** Meta object code from reading C++ file 'qquickwebviewloadrequest_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwebview/src/quick/qquickwebviewloadrequest_p.h"
#include <QtWebViewQuick/private/qquickwebviewloadrequest_p.h>
#include <QtWebViewQuick/private/qquickwebviewsettings_p.h>
#include <QtWebView/qwebviewloadinginfo.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquickwebviewloadrequest_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24QQuickWebViewLoadRequestE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuickWebViewLoadRequest::qt_create_metaobjectdata<qt_meta_tag_ZN24QQuickWebViewLoadRequestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuickWebViewLoadRequest",
        "QML.Element",
        "WebViewLoadRequest",
        "QML.AddedInVersion",
        "257",
        "QML.ExtraVersion",
        "512",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "url",
        "QUrl",
        "status",
        "QQuickWebView::LoadStatus",
        "errorString"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'url'
        QtMocHelpers::PropertyData<QUrl>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'status'
        QtMocHelpers::PropertyData<QQuickWebView::LoadStatus>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'errorString'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
    });
    return QtMocHelpers::metaObjectData<QQuickWebViewLoadRequest, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN24QQuickWebViewLoadRequestE[] = {
    QMetaObject::SuperData::link<QQuickWebView::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QQuickWebViewLoadRequest::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuickWebViewLoadRequestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuickWebViewLoadRequestE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN24QQuickWebViewLoadRequestE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24QQuickWebViewLoadRequestE_t>.metaTypes,
    nullptr
} };

void QQuickWebViewLoadRequest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuickWebViewLoadRequest *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->url(); break;
        case 1: *reinterpret_cast<QQuickWebView::LoadStatus*>(_v) = _t->status(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->errorString(); break;
        default: break;
        }
    }
}

const QMetaObject *QQuickWebViewLoadRequest::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuickWebViewLoadRequest::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuickWebViewLoadRequestE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuickWebViewLoadRequest::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
