/****************************************************************************
** Meta object code from reading C++ file 'qquickwebviewsettings_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwebview/src/quick/qquickwebviewsettings_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquickwebviewsettings_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21QQuickWebViewSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuickWebViewSettings::qt_create_metaobjectdata<qt_meta_tag_ZN21QQuickWebViewSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuickWebViewSettings",
        "QML.Element",
        "WebViewSettings",
        "QML.AddedInVersion",
        "1541",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "localStorageEnabledChanged",
        "javaScriptEnabledChanged",
        "allowFileAccessChanged",
        "localContentCanAccessFileUrlsChanged",
        "setLocalStorageEnabled",
        "enabled",
        "setJavaScriptEnabled",
        "setAllowFileAccess",
        "setLocalContentCanAccessFileUrls",
        "localStorageEnabled",
        "javaScriptEnabled",
        "allowFileAccess",
        "localContentCanAccessFileUrls"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'localStorageEnabledChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'javaScriptEnabledChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allowFileAccessChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'localContentCanAccessFileUrlsChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setLocalStorageEnabled'
        QtMocHelpers::SlotData<void(bool)>(13, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'setJavaScriptEnabled'
        QtMocHelpers::SlotData<void(bool)>(15, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'setAllowFileAccess'
        QtMocHelpers::SlotData<void(bool)>(16, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'setLocalContentCanAccessFileUrls'
        QtMocHelpers::SlotData<void(bool)>(17, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'localStorageEnabled'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'javaScriptEnabled'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'allowFileAccess'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'localContentCanAccessFileUrls'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<QQuickWebViewSettings, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuickWebViewSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuickWebViewSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuickWebViewSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21QQuickWebViewSettingsE_t>.metaTypes,
    nullptr
} };

void QQuickWebViewSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuickWebViewSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->localStorageEnabledChanged(); break;
        case 1: _t->javaScriptEnabledChanged(); break;
        case 2: _t->allowFileAccessChanged(); break;
        case 3: _t->localContentCanAccessFileUrlsChanged(); break;
        case 4: _t->setLocalStorageEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->setJavaScriptEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->setAllowFileAccess((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->setLocalContentCanAccessFileUrls((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuickWebViewSettings::*)()>(_a, &QQuickWebViewSettings::localStorageEnabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuickWebViewSettings::*)()>(_a, &QQuickWebViewSettings::javaScriptEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuickWebViewSettings::*)()>(_a, &QQuickWebViewSettings::allowFileAccessChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuickWebViewSettings::*)()>(_a, &QQuickWebViewSettings::localContentCanAccessFileUrlsChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->localStorageEnabled(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->javaScriptEnabled(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->allowFileAccess(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->localContentCanAccessFileUrls(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLocalStorageEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setJavaScriptEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setAllowFileAccess(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setLocalContentCanAccessFileUrls(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuickWebViewSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuickWebViewSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuickWebViewSettingsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuickWebViewSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QQuickWebViewSettings::localStorageEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuickWebViewSettings::javaScriptEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuickWebViewSettings::allowFileAccessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuickWebViewSettings::localContentCanAccessFileUrlsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
