/****************************************************************************
** Meta object code from reading C++ file 'qquickwebview_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwebview/src/quick/qquickwebview_p.h"
#include <QtWebViewQuick/private/qquickwebviewloadrequest_p.h>
#include <QtWebViewQuick/private/qquickwebviewsettings_p.h>
#include <QtWebView/qwebviewloadinginfo.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquickwebview_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13QQuickWebViewE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuickWebView::qt_create_metaobjectdata<qt_meta_tag_ZN13QQuickWebViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuickWebView",
        "QML.Element",
        "WebView",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "titleChanged",
        "",
        "urlChanged",
        "loadingChanged",
        "QQuickWebViewLoadRequest*",
        "loadRequest",
        "loadProgressChanged",
        "httpUserAgentChanged",
        "cookieAdded",
        "domain",
        "name",
        "cookieRemoved",
        "goBack",
        "goForward",
        "reload",
        "stop",
        "loadHtml",
        "html",
        "QUrl",
        "baseUrl",
        "runJavaScript",
        "script",
        "QJSValue",
        "callback",
        "setCookie",
        "value",
        "deleteCookie",
        "deleteAllCookies",
        "onLoadingChanged",
        "QWebViewLoadingInfo",
        "httpUserAgent",
        "url",
        "loading",
        "loadProgress",
        "title",
        "canGoBack",
        "canGoForward",
        "settings",
        "QQuickWebViewSettings*",
        "LoadStatus",
        "LoadStartedStatus",
        "LoadStoppedStatus",
        "LoadSucceededStatus",
        "LoadFailedStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadingChanged'
        QtMocHelpers::RevisionedSignalData<void(QQuickWebViewLoadRequest *)>(10, 8, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'loadProgressChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'httpUserAgentChanged'
        QtMocHelpers::RevisionedSignalData<void()>(14, 8, QMC::AccessPublic, 0x10e, QMetaType::Void),
        // Signal 'cookieAdded'
        QtMocHelpers::RevisionedSignalData<void(const QString &, const QString &)>(15, 8, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'cookieRemoved'
        QtMocHelpers::RevisionedSignalData<void(const QString &, const QString &)>(18, 8, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'goBack'
        QtMocHelpers::SlotData<void()>(19, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goForward'
        QtMocHelpers::SlotData<void()>(20, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(21, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(22, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadHtml'
        QtMocHelpers::RevisionedSlotData<void(const QString &, const QUrl &)>(23, 8, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'loadHtml'
        QtMocHelpers::RevisionedSlotData<void(const QString &)>(23, 8, QMC::AccessPublic | QMC::MethodCloned, 0x101, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'runJavaScript'
        QtMocHelpers::RevisionedSlotData<void(const QString &, const QJSValue &)>(27, 8, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { 0x80000000 | 29, 30 },
        }}),
        // Slot 'runJavaScript'
        QtMocHelpers::RevisionedSlotData<void(const QString &)>(27, 8, QMC::AccessPublic | QMC::MethodCloned, 0x101, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'setCookie'
        QtMocHelpers::RevisionedSlotData<void(const QString &, const QString &, const QString &)>(31, 8, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 32 },
        }}),
        // Slot 'deleteCookie'
        QtMocHelpers::RevisionedSlotData<void(const QString &, const QString &)>(33, 8, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'deleteAllCookies'
        QtMocHelpers::RevisionedSlotData<void()>(34, 8, QMC::AccessPublic, 0x603, QMetaType::Void),
        // Slot 'onLoadingChanged'
        QtMocHelpers::SlotData<void(const QWebViewLoadingInfo &)>(35, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'httpUserAgent'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4, 0x10e),
        // property 'url'
        QtMocHelpers::PropertyData<QUrl>(38, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
        // property 'loading'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 2, 0x101),
        // property 'loadProgress'
        QtMocHelpers::PropertyData<int>(40, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 3),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 0),
        // property 'canGoBack'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'canGoForward'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'settings'
        QtMocHelpers::PropertyData<QQuickWebViewSettings*>(44, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final, -1, 0x605),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'LoadStatus'
        QtMocHelpers::EnumData<enum LoadStatus>(46, 46, QMC::EnumFlags{}).add({
            {   47, LoadStatus::LoadStartedStatus },
            {   48, LoadStatus::LoadStoppedStatus },
            {   49, LoadStatus::LoadSucceededStatus },
            {   50, LoadStatus::LoadFailedStatus },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQuickWebView, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuickWebView::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickWindowContainer::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QQuickWebViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QQuickWebViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QQuickWebViewE_t>.metaTypes,
    nullptr
} };

void QQuickWebView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuickWebView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->titleChanged(); break;
        case 1: _t->urlChanged(); break;
        case 2: _t->loadingChanged((*reinterpret_cast<std::add_pointer_t<QQuickWebViewLoadRequest*>>(_a[1]))); break;
        case 3: _t->loadProgressChanged(); break;
        case 4: _t->httpUserAgentChanged(); break;
        case 5: _t->cookieAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->cookieRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->goBack(); break;
        case 8: _t->goForward(); break;
        case 9: _t->reload(); break;
        case 10: _t->stop(); break;
        case 11: _t->loadHtml((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 12: _t->loadHtml((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->runJavaScript((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2]))); break;
        case 14: _t->runJavaScript((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->setCookie((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 16: _t->deleteCookie((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->deleteAllCookies(); break;
        case 18: _t->onLoadingChanged((*reinterpret_cast<std::add_pointer_t<QWebViewLoadingInfo>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuickWebView::*)()>(_a, &QQuickWebView::titleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuickWebView::*)()>(_a, &QQuickWebView::urlChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuickWebView::*)(QQuickWebViewLoadRequest * )>(_a, &QQuickWebView::loadingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuickWebView::*)()>(_a, &QQuickWebView::loadProgressChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuickWebView::*)()>(_a, &QQuickWebView::httpUserAgentChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuickWebView::*)(const QString & , const QString & )>(_a, &QQuickWebView::cookieAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuickWebView::*)(const QString & , const QString & )>(_a, &QQuickWebView::cookieRemoved, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->httpUserAgent(); break;
        case 1: *reinterpret_cast<QUrl*>(_v) = _t->url(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isLoading(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->loadProgress(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->canGoBack(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->canGoForward(); break;
        case 7: *reinterpret_cast<QQuickWebViewSettings**>(_v) = _t->settings(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setHttpUserAgent(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setUrl(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuickWebView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuickWebView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QQuickWebViewE_t>.strings))
        return static_cast<void*>(this);
    return QQuickWindowContainer::qt_metacast(_clname);
}

int QQuickWebView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickWindowContainer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void QQuickWebView::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuickWebView::urlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuickWebView::loadingChanged(QQuickWebViewLoadRequest * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QQuickWebView::loadProgressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuickWebView::httpUserAgentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuickWebView::cookieAdded(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void QQuickWebView::cookieRemoved(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}
QT_WARNING_POP
